@@ -7,6 +7,8 @@ import android.util.Log;
 import com.fewlaps.flone.DesiredYawCalculator;
 import com.fewlaps.flone.data.KnownDronesDatabase;
 import com.fewlaps.flone.data.bean.Drone;
+import com.fewlaps.flone.io.bean.ActualArmedData;
+import com.fewlaps.flone.io.bean.ArmedDataChangeRequest;
 import com.fewlaps.flone.io.bean.DroneConnectionStatusChanged;
 import com.fewlaps.flone.io.bean.DroneSensorData;
 import com.fewlaps.flone.io.communication.Bluetooth;
@@ -28,8 +30,13 @@ import de.greenrobot.event.EventBus;
  * @date 15/02/2015
  */
 public class DroneService extends BaseService {
-    public static String ACTION_CONNECT = "connect";
-    public static String ACTION_DISCONNECT = "disconnect";
+    public static final boolean ARMED_DEFAULT = false;
+
+    public static final Object ACTION_GET_ARMED = "getArmed";
+    public static final String ACTION_CONNECT = "connect";
+    public static final String ACTION_DISCONNECT = "disconnect";
+
+    private boolean armed = ARMED_DEFAULT;
 
     private static final int BAUD_RATE = 115200; //The baud rate where the BT works
 
@@ -80,6 +87,8 @@ public class DroneService extends BaseService {
             running = false;
             stopForeground(true);
             stopSelf();
+        } else if (action.equals(ACTION_GET_ARMED)) {
+            EventBus.getDefault().post(new ActualArmedData(armed));
         }
     }
 
@@ -94,23 +103,39 @@ public class DroneService extends BaseService {
      * to do before sending the RC to the drone, to make it fly as the user excepts
      */
     private void updateRCWithInputData() {
-        Log.i("HEADING", "phone: " + userInput.getHeading() + "   drone: " + droneInput.getHeading());
+//        Log.i("HEADING", "phone: " + userInput.getHeading() + "   drone: " + droneInput.getHeading());
 
         int yaw = (int) yawCalculator.getYaw(droneInput.getHeading(), userInput.getHeading());
         int pitch = (int) userInput.getPitch();
         int roll = (int) userInput.getRoll();
 
-        rc.setThrottle(userInput.getThrottle());
-        rc.setAdjustedYaw(yaw);
-        rc.setPitch(pitch);
-        rc.setRoll(roll);
+        if (armed) {
+            rc.set(RCSignals.AUX1, RCSignals.RC_MAX);
+            rc.setThrottle((int) userInput.getThrottle());
+
+            yaw = (int) yawCalculator.getYaw(droneInput.getHeading(), userInput.getHeading());
+            pitch = (int) userInput.getPitch();
+            roll = (int) userInput.getRoll();
+        } else {
+            rc.set(RCSignals.AUX1, RCSignals.RC_MIN);
+            rc.setThrottle(RCSignals.RC_MIN);
+
+            yaw = RCSignals.RC_MID;
+            pitch = RCSignals.RC_MID;
+            roll = RCSignals.RC_MID;
+        }
+
+//        rc.setAdjustedYaw(yaw); //while having the compass issue, sending 1500 to the board
+        rc.setYaw(1500);
+        rc.setRoll(pitch);
+        rc.setPitch(roll);
 
         phoneOutputData.update(yaw, pitch, roll);
         EventBus.getDefault().post(phoneOutputData);
     }
 
-    public void onEventMainThread(DroneSensorData sensorInformation) {
-        droneInput = sensorInformation;
+    public void onEventMainThread(DroneSensorData droneSensorData) {
+        droneInput = droneSensorData;
 
         protocol.SendRequestMSP_ATTITUDE();
         lastDroneAnswerReceived = System.currentTimeMillis();
@@ -119,6 +144,11 @@ public class DroneService extends BaseService {
         protocol.SendRequestMSP_SET_RAW_RC(rc.get());
     }
 
+    public void onEventMainThread(ArmedDataChangeRequest armedDataChangeRequest) {
+        armed = armedDataChangeRequest.isArmed();
+        EventBus.getDefault().post(new ActualArmedData(armed));
+    }
+
     private final Runnable reconnectRunnable = new Runnable() {
         public void run() {
             if (running) {
